Simulations
=================

.. toctree::

    nghxrg.rst
    ngnrc.rst

.. rubric:: Summary

.. autosummary::

    pynrc.simul.nghxrg.HXRGNoise
    pynrc.simul.ngNRC.SCAnoise
    pynrc.simul.ngNRC.slope_to_ramp
